@@ -191,8 +191,11 @@ impl TokenSink for TokenPrinter {
                             || attr.name.local.as_bytes() == b"defer")
                     {
                         write!(&mut self.current, " {}", attr.name.local).unwrap();
+                    } else if attr.value.chars().any(|x| x == '"') && attr.value.chars().all(|x| x != '\'') {
+                        write!(&mut self.current, " {}='{}'", attr.name.local, attr.value)
+                            .unwrap();
                     } else {
-                        write!(&mut self.current, " {}=\"{}\"", attr.name.local, attr.value)
+                        write!(&mut self.current, " {}=\"{}\"", attr.name.local, attr.value.replace("\"", "&#34;"))
                             .unwrap();
                     }
                 }
